@@ -131,6 +131,7 @@ class FeatureVisualization:
                 # TODO: test stack
                 data_broadcast = torch.stack(data_broadcast, dim=0)
                 sample_indices = np.array(sample_indices)
+                targets = np.array(targets)
 
             except NotImplementedError:
                 data_broadcast, targets, sample_indices = data_batch, targets_samples, samples_batch
@@ -162,10 +163,10 @@ class FeatureVisualization:
         """
         Finds input samples that maximally activate each neuron in a layer and most relevant samples
         """
-        # TODO: dummy target for extra dataset
-        d_c_sorted, rel_c_sorted, rf_c_sorted = self.RelMax.analyze_layer(rel, concept, layer_name, data_indices)
+        d_c_sorted, rel_c_sorted, rf_c_sorted, t_c_sorted = self.RelMax.analyze_layer(
+            rel, concept, layer_name, data_indices, targets)
 
-        self.RelStats.analyze_layer(d_c_sorted, rel_c_sorted, rf_c_sorted, layer_name, targets)
+        self.RelStats.analyze_layer(d_c_sorted, rel_c_sorted, rf_c_sorted, t_c_sorted, layer_name)
 
     @torch.no_grad()
     def analyze_activation(self, act, layer_name, concept, data_indices, targets):
@@ -179,9 +180,10 @@ class FeatureVisualization:
         act = act[unique_indices]
         targets = targets[unique_indices]
 
-        d_c_sorted, act_c_sorted, rf_c_sorted = self.ActMax.analyze_layer(act, concept, layer_name, data_indices)
+        d_c_sorted, act_c_sorted, rf_c_sorted, t_c_sorted = self.ActMax.analyze_layer(
+            act, concept, layer_name, data_indices, targets)
 
-        self.ActStats.analyze_layer(d_c_sorted, act_c_sorted, rf_c_sorted, layer_name, targets)
+        self.ActStats.analyze_layer(d_c_sorted, act_c_sorted, rf_c_sorted, t_c_sorted, layer_name)
 
     def _save_results(self, d_index=None):
 
